==> nexus3_cli-3.4.0-py3-none-any.whl: nexuscli/api/repository/recipes/apt.py <==
from nexuscli.api.repository.base_models import Repository
from nexuscli.api.repository.base_models import HostedRepository
from nexuscli.api.repository.base_models import ProxyRepository

__all__ = ['AptHostedRepository', 'AptProxyRepository', 'AptGroupRepository']


class _AptRepository(Repository):
    DEFAULT_RECIPE = 'apt'
    RECIPES = ('apt',)

    def __init__(self, name: str, distribution: str = 'bionic', **kwargs):
        self.distribution = distribution
        kwargs.update({'recipe': 'apt'})
        super().__init__(name, **kwargs)

    @property
    def configuration(self):
        repo_config = super().configuration

        repo_config['attributes'].update({
            'apt': {
                'distribution': self.distribution,
            }
        })

        return repo_config


class AptHostedRepository(_AptRepository, HostedRepository):
    def __init__(self, name: str, gpg_keypair: str = None, passphrase: str = None, **kwargs):
        self.gpg_keypair = gpg_keypair
        self.passphrase = passphrase
        super().__init__(name, **kwargs)

    @property
    def configuration(self):
        repo_config = super().configuration
        repo_config['attributes'].update({
            'aptSigning': {
                'keypair': self.gpg_keypair,
                'passphrase': self.passphrase
            }
        })

        return repo_config


class AptProxyRepository(_AptRepository, ProxyRepository):
    def __init__(self, name,
                 flat=False,
                 **kwargs):
        self.flat = flat
        super().__init__(name, **kwargs)

    @property
    def configuration(self):
        repo_config = super().configuration

        repo_config['attributes']['apt']['flat'] = self.flat

        return repo_config


class AptGroupRepository:
    def __init__(self):
        raise NotImplementedError

==> nexus3_cli-4.1.6-py3-none-any.whl: nexuscli/api/repository/recipes/apt.py <==
from typing import Optional

from nexuscli.api.repository.base_models import Repository
from nexuscli.api.repository.base_models import HostedRepository
from nexuscli.api.repository.base_models import ProxyRepository

__all__ = ['AptHostedRepository', 'AptProxyRepository', 'AptGroupRepository']


class _AptRepository(Repository):
    RECIPE_NAME = 'apt'

    def __init__(self, *args, **kwargs):
        self.distribution: str = kwargs.get('distribution', 'bionic')

        super().__init__(*args, **kwargs)

    @property
    def configuration(self):
        repo_config = super().configuration

        repo_config['attributes'].update({
            'apt': {
                'distribution': self.distribution,
            }
        })

        return repo_config


class AptHostedRepository(_AptRepository, HostedRepository):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.gpg_keypair: Optional[str] = kwargs.get('gpg_keypair')
        self.passphrase: Optional[str] = kwargs.get('passphrase')

    @property
    def configuration(self):
        repo_config = super().configuration
        repo_config['attributes'].update({
            'aptSigning': {
                'keypair': self.gpg_keypair,
                'passphrase': self.passphrase
            }
        })

        return repo_config


class AptProxyRepository(_AptRepository, ProxyRepository):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.flat: bool = kwargs.get('flat', False)

    @property
    def configuration(self):
        repo_config = super().configuration

        repo_config['attributes']['apt']['flat'] = self.flat

        return repo_config


class AptGroupRepository:
    def __init__(self):
        raise NotImplementedError
